/* beat.c -- beat-detection code
 *
 * Copyright (C) 2001 Janusz Gregorczyk <jgregor@kki.net.pl>
 *
 * This file is part of xvs.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 */

#include <glib.h>
#include <math.h>

#include "beat.h"

extern gint16 XVS_pcm_data[2][512];
extern gint16 XVS_freq_data[2][256];

/* Beat detection routines need a lot of tweaking. I would 
 * like xvs to detect rhythm independent of music loudness.
 * Beat detection should also be customizable.
 */
gboolean detect_beat (void) {
  int x;
  int total, min, max;
  gboolean beat;
  static int prev_total;

  total = 0;

  min = XVS_pcm_data[0][0];
  max = XVS_pcm_data[0][0];

  for (x = 1; x < 512; x++) {
    total += abs (XVS_pcm_data[0][x] - XVS_pcm_data[0][x - 1]);
    if (XVS_pcm_data[0][x] < min) min = XVS_pcm_data[0][x];
    if (XVS_pcm_data[0][x] > max) max = XVS_pcm_data[0][x];
  }

  total /= 512;

  beat = total > (2 * prev_total);

  prev_total = total;

  return beat;
}
