/* fx.h -- an fx-module interface
 *
 * Copyright (C) 2001 Janusz Gregorczyk <jgregor@kki.net.pl>
 *
 * This file is part of xvs.
 *
 * Portions of this file are derived from `Paranormal' plugin:
 *   paranormal
 *   Copyright (C) 2001 Jamie Gennis <jgennis@mindspring.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 */
 
#ifndef Included_FX_H
#define Included_FX_H

#include <glib.h>
#include <gtk/gtk.h>

#include "image.h"

/* This is used to signal that the module used 
   an auxillary buffer to perform its operation. */
enum { FB_ERROR = 0,
       FB_NIL = 1,
       FB_SINGLE = 2,
       FB_AUX = 3 };

/* The following structures describe configurable options of each module. */
typedef union XVS_Option_Value {
  gint ival;
  gfloat fval;
  gchar *sval;
  gboolean bval;
} XVS_Option_Value;

typedef struct XVS_Option_Desc {
  char *id;
  enum {
    XVS_OPT_INT = 0,
    XVS_OPT_FLOAT = 1,
    XVS_OPT_STRING = 2,
    XVS_OPT_BOOLEAN = 3
  } type;
  XVS_Option_Value default_value;
} XVS_Option_Desc;

typedef struct XVS_Option {
  const XVS_Option_Desc *desc;
  XVS_Option_Value value;
} XVS_Option;

struct XVS_Effect;

/* This is a description of an effect (a class). */
typedef struct XVS_Effect_Desc {
  char *id;			/* Effect ID */
  const XVS_Option_Desc *options;

  enum {
    XVS_FLAG_CONTAINER = 0x1
  } flags;

  char* (*get_desc)(void); 
  void (*init)(struct XVS_Effect *fx);
  int (*render)(struct XVS_Effect *fx,
		XVS_Image *img, XVS_Image *img_aux, gboolean beat);
  void (*cleanup)(struct XVS_Effect *fx);
  GtkWidget* (*configure)(struct XVS_Effect *fx);
} XVS_Effect_Desc;

/* This is an actual instance of the effect (an object). */
typedef struct XVS_Effect {
  const XVS_Effect_Desc *desc;
  enum {
    XVS_FX_ENABLED = 0x1
  } state;
  XVS_Option *config;
  GList *children;
  void *data;
} XVS_Effect;

/* Functions to manage fx modules. */

const XVS_Effect_Desc *fx_find_driver (const char* fxname);

XVS_Effect *fx_create (const XVS_Effect_Desc *desc);
XVS_Effect *fx_clone (const XVS_Effect *fx);
void fx_destroy (XVS_Effect *fx);
void fx_render (XVS_Effect *fx, 
		XVS_Image *img, XVS_Image *img_aux, gboolean beat);

XVS_Effect *container_clone (XVS_Effect *copy, const XVS_Effect *fx);
void container_destroy (XVS_Effect *fx);
void container_add_fx (XVS_Effect *fx, XVS_Effect *child);
void container_add_fx_before (XVS_Effect *fx, 
			      XVS_Effect *child, XVS_Effect *sibling);
void container_add_fx_after (XVS_Effect *fx,
			     XVS_Effect *child, XVS_Effect *sibling);
void container_remove_fx (XVS_Effect *fx, XVS_Effect *child);

/* Extern variables. */

/* In fxlist.c: */
extern const XVS_Effect_Desc* fxdrivers[];

/* In plugin.c: */
extern gint16 XVS_pcm_data[2][512];
extern gint16 XVS_freq_data[2][256];

#endif /* Included_FX_H */
