/* clear.c -- clears screen
 *
 * Copyright (C) 2001 Janusz Gregorczyk <jgregor@kki.net.pl>
 *
 * This file is part of xvs.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 */

#include "../fx.h"
#include "../image.h"
#include "../widgets/color_button.h"

static char* get_desc (void);
static int render (XVS_Effect *fx, 
                   XVS_Image *img, XVS_Image *img_aux, gboolean beat);
static GtkWidget* configure (XVS_Effect *fx);

/* Module options. */
static const XVS_Option_Desc FXClear_Option_Desc[] = {
  { "color", XVS_OPT_INT, { .ival = 0x00000000 } },
  { 0 }
};

/* Module description. */
XVS_Effect_Desc FXClear = {
  "Render/Clear",
  FXClear_Option_Desc,
  0,
  
  &get_desc,
  NULL,
  &render,
  NULL,
  &configure,
};

/* Module code. */
static char* get_desc (void) {
  return "Clear";
}

static int render (XVS_Effect *fx, XVS_Image *img, XVS_Image *img_aux,
		   gboolean beat) {
  gint opt_color = fx->config[0].value.ival;
		   
  XVS_img_clear (img, opt_color);
  return FB_SINGLE;
}

static void color_changed (Color_Button *cb, gint *value) {
  *value = cb->color;
}    

static GtkWidget* configure (XVS_Effect *fx) {
  GtkWidget *hbox, *button, *label;
  gint *opt_color = &fx->config[0].value.ival;
  
  hbox = gtk_hbox_new (FALSE, 4);
  gtk_widget_show (hbox);
    
  label = gtk_label_new ("Colour");
  gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
  gtk_widget_show (label);

  button = color_button_new ();
  color_button_set_color (COLOR_BUTTON(button), *opt_color);
  gtk_signal_connect (GTK_OBJECT(button), "color-changed", 
                      GTK_SIGNAL_FUNC(color_changed), opt_color);
  gtk_box_pack_start (GTK_BOX(hbox), button, FALSE, FALSE, 0);
  gtk_widget_show (button);

  return hbox;
}
