/* comment.c -- provides a comment field in its settings box
 *
 * Copyright (C) 2001 Janusz Gregorczyk <jgregor@kki.net.pl>
 *
 * This file is part of xvs.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 */

#include "../fx.h"
#include "../image.h"

static char* get_desc (void);
static GtkWidget* configure (XVS_Effect *fx);

/* Module options. */
static const XVS_Option_Desc FXComment_Option_Desc[] = {
  { "comment", XVS_OPT_STRING, { .sval = NULL } },
  { 0 }
};

/* Module description. */
XVS_Effect_Desc FXComment = {
  "Misc/Comment",
  FXComment_Option_Desc,
  0,
  
  &get_desc,
  NULL,
  NULL,
  NULL,
  &configure
};

/* Module code. */
static char* get_desc (void) {
  return "Comment";
}

static void on_text_change (GtkEditable *editable, gchar **value) {
  g_free (*value);
  *value = gtk_editable_get_chars (editable, 0, -1);
}

static GtkWidget* configure (XVS_Effect *fx) {
  GtkWidget *text;
  gchar **opt_comment = &fx->config[0].value.sval;

  text = gtk_text_new (NULL, NULL); 

  gtk_text_freeze (GTK_TEXT(text));
  gtk_text_insert (GTK_TEXT(text), NULL, NULL, NULL, *opt_comment, -1);
  gtk_text_thaw (GTK_TEXT(text));

  gtk_text_set_editable (GTK_TEXT(text), TRUE);
  gtk_text_set_word_wrap (GTK_TEXT(text), TRUE);
  gtk_signal_connect (GTK_OBJECT(text), "changed", 
		      GTK_SIGNAL_FUNC(on_text_change), opt_comment);

  return text;
}
