/* once.c -- a `once-only' container
 *
 * Copyright (C) 2001 Janusz Gregorczyk <jgregor@kki.net.pl>
 *
 * This file is part of xvs.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 */

#include "../fx.h"
#include "../image.h"

static char* get_desc (void);
static void init (XVS_Effect *fx);
static int render (XVS_Effect *fx, XVS_Image *img, XVS_Image *img_aux,
		   gboolean beat);
static void cleanup (XVS_Effect *fx);

/* No options. */

/* Module data. */
typedef struct {
  gboolean done;
} FXOnce_Data;

/* Module description. */
XVS_Effect_Desc FXOnce = {
  "Container/Once",
  NULL,
  XVS_FLAG_CONTAINER,
  
  &get_desc,
  &init,
  &render,
  &cleanup,
  NULL
};

/* Module code. */
static char* get_desc (void) {
  return "Once container";
}

static void init (XVS_Effect *fx) {
  fx->data = g_new (FXOnce_Data, 1);
  
  {
    FXOnce_Data *data = (FXOnce_Data *)fx->data;
    
    data->done = FALSE;
  }
}

static int render (XVS_Effect *fx, XVS_Image *img, XVS_Image *img_aux,
		   gboolean beat) {
  FXOnce_Data *data = (FXOnce_Data *)fx->data;
  GList *child;

  if (data->done) return FB_NIL;
  
  child = fx->children;
  while (child) {
    XVS_Effect *child_fx = (XVS_Effect *)child->data;
    fx_render (child_fx, img, img_aux, beat);
    child = child->next;
  }

  data->done = TRUE;

  return FB_SINGLE;
}

static void cleanup (XVS_Effect *fx) {
  FXOnce_Data *data = (FXOnce_Data *)fx->data;
  
  g_free (data);
}
