/* fxcontainer.c -- operations on containers
 *
 * Copyright (C) 2001 Janusz Gregorczyk <jgregor@kki.net.pl>
 *
 * This file is part of xvs.
 *
 * Portions of this file are derived from `Paranormal' plugin:
 *   paranormal
 *   Copyright (C) 2001 Jamie Gennis <jgennis@mindspring.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 */

#include <glib.h>
 
#include "fx.h"

XVS_Effect *container_clone (XVS_Effect *copy, const XVS_Effect *fx) {
  GList *child;

  g_assert (fx);
  g_assert (fx->desc->flags & XVS_FLAG_CONTAINER);

  child = fx->children;
  while (child) {
    XVS_Effect *child_copy = fx_clone ((XVS_Effect *)child->data);

    copy->children = g_list_append (copy->children, child_copy);

    child = child->next;
  }

  return NULL;
}

void container_destroy (XVS_Effect *fx) {
  GList *child;

  g_assert (fx);
  g_assert (fx->desc->flags & XVS_FLAG_CONTAINER);

  child = fx->children;
  while (child) {
    fx_destroy ((XVS_Effect *)child->data);
    child = g_list_next (child);
  }

  g_list_free (fx->children);
  fx->children = NULL;
}

void container_add_fx (XVS_Effect *fx, XVS_Effect *child) {
  g_assert (fx);
  g_assert (fx->desc->flags & XVS_FLAG_CONTAINER);
  g_assert (child);

  fx->children = g_list_append (fx->children, child);
}

void container_add_fx_before (XVS_Effect *fx, 
			      XVS_Effect *child, XVS_Effect *sibling) {
  g_assert (fx);
  g_assert (fx->desc->flags & XVS_FLAG_CONTAINER);
  g_assert (child);

  if (!sibling) {
    fx->children = g_list_append (fx->children, child);
  } else {
    GList *sibling_node = g_list_find (fx->children, sibling);

    int pos = g_list_position (fx->children, sibling_node);

    fx->children = g_list_insert (fx->children, child, pos);
  }
}

void container_add_fx_after (XVS_Effect *fx, 
			     XVS_Effect *child, XVS_Effect *sibling) {
  g_assert (fx);
  g_assert (fx->desc->flags & XVS_FLAG_CONTAINER);
  g_assert (child);

  if (!sibling) {
    fx->children = g_list_append (fx->children, child);
  } else {
    GList *sibling_node = g_list_find (fx->children, sibling);

    int pos = g_list_position (fx->children, sibling_node);

    fx->children = g_list_insert (fx->children, child, pos + 1);
  }
}

void container_remove_fx (XVS_Effect *fx, XVS_Effect *child) {
  g_assert (fx);
  g_assert (fx->desc->flags & XVS_FLAG_CONTAINER);
  g_assert (child);

  fx->children = g_list_remove (fx->children, child);
}
