/* fxlist.c -- a list of built-in modules
 *
 * Copyright (C) 2001 Janusz Gregorczyk <jgregor@kki.net.pl>
 *
 * This file is part of xvs.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 */
 
#include <glib.h>
#include <string.h>

#include "fx.h"

/* This code utilizes a nifty technique used in xmame sources.
 * The contents of this file is included twice by itself, 
 * first to predeclare external structures and then to put 
 * them into an array.
 */

#ifndef FXLIST_RECURSIVE
#define FXLIST_RECURSIVE

/* declare all external references */
#define FXMODULE(NAME) extern XVS_Effect_Desc NAME;
#include "fxlist.c"
#undef FXMODULE

/* fill in fxdrivers[] array */
#define FXMODULE(NAME) &##NAME,

const XVS_Effect_Desc *fxdrivers[] = {
#include "fxlist.c"
  0	/* end of array  */
};

const XVS_Effect_Desc *fx_find_driver (const char* fxid) {
  const XVS_Effect_Desc **fx = &fxdrivers[0];

  g_assert (fxid);

  while (*fx) {
    if (strcmp (fxid, (*fx)->id) == 0) {
      return *fx;
    }
    fx++;
  }

  return NULL;
}

#else /* FXLIST_RECURSIVE */

/* List all available modules. */
/* Filters */
FXMODULE( FXBlur )
FXMODULE( FXBump )
/* Transitions */
FXMODULE( FXZoomer )
FXMODULE( FXRotoZoomer )
FXMODULE( FXUniBlitter )
/* Renderers */
FXMODULE( FXClear )
FXMODULE( FXFlash )
FXMODULE( FXParticle )
FXMODULE( FXScope )
FXMODULE( FXRing )
FXMODULE( FXUniScope )
/* Containers */
FXMODULE( FXSimple )
FXMODULE( FXOnce )
/* Other */
FXMODULE( FXComment )

#endif /* FXLIST_RECURSIVE */
