/* image.c -- image manipulation
 *
 * Copyright (C) 2001 Janusz Gregorczyk <jgregor@kki.net.pl>
 *
 * This file is part of xvs.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 
 */

#include <glib.h>
#include <stdlib.h>
#include <string.h>

#include "image.h"

XVS_Image *XVS_img_create (int width, int height) { 
  XVS_Image *img;
  
  img = (XVS_Image *)g_malloc (sizeof(XVS_Image));

  img->w = width;
  img->h = height;

  img->pixels = (guint32 *)g_malloc0 ((guint)(img->w) * (guint)(img->h)
				     * sizeof (img->pixels[0]));
  
  return img;
}

void XVS_img_free (XVS_Image *img) {
  g_assert (img);

  g_free (img->pixels);

  g_free (img);
}

XVS_Image *XVS_img_resize (XVS_Image *img, int width, int height) {
  XVS_Image *new_img;

  g_assert (img);

  XVS_img_free (img);

  new_img = XVS_img_create (width, height);

  return new_img;
}

void XVS_img_copy (XVS_Image *dest, XVS_Image *src) {
  g_assert (dest);
  g_assert (src);
  g_assert (dest->w ==src->w && dest->h == src->h);
  
  memcpy (dest->pixels, src->pixels, 
	  src->w * src->h * sizeof(dest->pixels[0]));
}

void XVS_img_clear (XVS_Image *img, guint32 rgb) {
  int npixels = img->h * img->w;
  guint32 *ptr = img->pixels;
  
  g_assert (img);

  while (npixels--) *ptr++ = rgb;
}
